@@ -1,6 +1,6 @@
 # 2016. 1. 10 by Hans Roh hansroh@gmail.com
 
-__version__ = "0.7.6.23"
+__version__ = "0.7.6.27"
 version_info = tuple (map (lambda x: not x.isdigit () and x or int (x),  __version__.split (".")))
 import threading
 from . import lifetime, queue, request_builder, response_builder, stubproxy
@@ -275,11 +275,8 @@ def fetchall ():
 			lifetime.lifetime_loop (os.name == "nt" and 1.0 or _timeout / 2.0, 1)
 			if sum ([1 for conn in asyncore.socket_map.values () if not isinstance (conn, async_dns) and conn.get_proto () in H2_PROTOCOLS and conn.connected and not conn.isactive ()]) == _workers:
 				_logger ('%d connection(s) created' % target_socks, 'info')
-				break			
-			if _finished_total == target_socks:
-				_logger ("can't connect remote host", "error")
-				sys.exit ()				
-		
+				break
+			
 	# now starting
 	while qsize () or _currents:
 		while _concurrent > min (len (_currents), mapsize ()) and qsize ():
