@@ -3,7 +3,7 @@
 # Hans Roh (hansroh@gmail.com)
 # 2015.6.9
 #-------------------------------------------------------
-
+		
 DEBUG = False
 
 try:
@@ -17,7 +17,7 @@ except ImportError:
 
 else:	
 	import asyncore
-	from . import dbconnect	
+	from . import dbconnect
 
 	from psycopg2.extensions import POLL_OK, POLL_WRITE, POLL_READ
 	_STATE_OK = (POLL_OK, POLL_WRITE, POLL_READ)
@@ -26,21 +26,28 @@ else:
 		def __init__ (self, address, params = None, lock = None, logger = None):
 			dbconnect.AsynDBConnect.__init__ (self, address, params, lock, logger)			
 			self.conn = None
-			self.cur = None
-			self.dbname, self.user, self.password = self.params
+			self.cur = None			
 			asyncore.dispatcher.__init__ (self)
 			
 		def check_state (self, state):
-			if state not in (_STATE_OK):
-				self.logger (self.exception_str, "psycopg2.poll() returned %s" % state)
-				self.handle_close (psycopg2.OperationalError, "psycopg2.poll() returned %s" % state)
+			if state not in (_STATE_OK):				
+				self.logger ("[warn] psycopg2.poll() returned %s" % state)
+				self.handle_close ()
 		
-		def poll (self):		
+		def poll (self):
+			# 2 cases, if on requesting raise immediatly, else handle silently
 			try:
 				return self.socket.poll ()
+			except psycopg2.OperationalError:				
+				if self.request:
+					raise
+				# else usually timeout	
 			except:
+				if self.request:
+					raise
+				# logging
 				self.logger.trace ()
-				return -1
+			return -1
 			
 		def writable (self):			
 			return self.out_buffer or not self.connected
@@ -67,7 +74,7 @@ else:
 				self.handle_connect ()
 				self.connected = True
 				self.connecting = False		
-			else:
+			else:				
 				self.check_state (state)
 		
 		def handle_write_event (self):		
@@ -84,7 +91,7 @@ else:
 			self.conn = self.socket
 			self.cur = self.conn.cursor()		
 			self.set_socket (self.cur.connection)			
-						
+					
 		def handle_read (self):
 			state = self.poll ()
 			if self.cur and state == POLL_OK:
@@ -100,7 +107,7 @@ else:
 				self.set_event_time ()				
 				self.cur.execute (self.out_buffer)
 				self.out_buffer = ""
-			else:
+			else:				
 				self.check_state (state)
 				
 		#-----------------------------------
@@ -108,10 +115,11 @@ else:
 		#-----------------------------------
 		def close_case (self):			
 			if self.request:
-				if self.has_result:
+				if self.has_result and self.cur.description:					
 					self.request.handle_result (self.cur.description, self.exception_class, self.exception_str, self.fetchall ())					
 				else:
 					self.request.handle_result (None, self.exception_class, self.exception_str, None)
+					self.has_result = False
 				self.request = None
 			self.set_active (False)
 			
@@ -122,20 +130,23 @@ else:
 				except psycopg2.ProgrammingError:
 					pass				
 		
-		def fetchall (self):		
+		def fetchall (self):
 			result = self.cur.fetchall ()
 			self.has_result = False
 			return result
 							
-		def close (self):			
+		def close (self, deactive = 1):
 			if self.cur:
-				self.cur.close ()
+				try:
+					self.cur.close ()
+				except psycopg2.ProgrammingError:
+					pass						
 				self.cur = None
 			if self.conn:	
-				self.conn.close ()			
+				self.conn.close ()
 				self.conn = None	
 				
-			dbconnect.AsynDBConnect.close (self)
+			dbconnect.AsynDBConnect.close (self, deactive)
 			asyncore.dispatcher.close (self)
 			
 		def connect (self, force = 0):
@@ -152,7 +163,7 @@ else:
 		
 		def end_tran (self):
 			self.del_channel ()
-				
+
 		def begin_tran (self, request):
 			dbconnect.AsynDBConnect.begin_tran (self, request)
 			self.out_buffer = request.params [0]
