@@ -16,18 +16,17 @@ class RedisError (Exception):
 class AsynConnect (dbconnect.AsynDBConnect, asynchat.async_chat):	
 	def __init__ (self, address, params = None, lock = None, logger = None):
 		dbconnect.AsynDBConnect.__init__ (self, address, params, lock, logger)
-		self.dbname, self.user, self.password = self.params
 		self.redis = redisconn.Connection ()
 		asynchat.async_chat.__init__ (self)
 	
-	def close (self):		
+	def close (self, deactive = 1):
 		asynchat.async_chat.close (self)				
 		# re-init asychat
 		self.ac_in_buffer = b''
 		self.incoming = []
 		self.producer_fifo.clear()
 				
-		dbconnect.AsynDBConnect.close (self)
+		dbconnect.AsynDBConnect.close (self, deactive)
 		self.logger ("[info] .....dbo %s:%d has been closed" % self.address)
 		
 	def handle_connect (self):
@@ -132,7 +131,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asynchat.async_chat):
 		if not self.num_elements:
 			self.has_result = True
 			self.close_case_with_end_tran ()
-	
+		
 	def close_case (self):
 		if self.request:
 			self.request.handle_result (None, self.exception_class, self.exception_str, self.fetchall ())
