@@ -14,6 +14,9 @@ responses = {
 		303: "See Other",
 		304: "Not Modified",
 		305: "Use Proxy",
+		306: "Switch Proxy",
+		307: "Temporary Redirect",
+		308: "Permanent Redirect",
 		400: "Bad Request",
 		401: "Unauthorized",
 		402: "Payment Required",
@@ -22,7 +25,7 @@ responses = {
 		405: "Method Not Allowed",
 		406: "Not Acceptable",
 		407: "Proxy Authentication Required",
-		408: "Request Time-out",
+		408: "Request Timeout",
 		409: "Conflict",
 		410: "Gone",
 		411: "Length Required",			
@@ -50,9 +53,19 @@ responses = {
 		708: "No Data Recieved",
 		709: "Invalid Content",
 		710: "Channel Closed",	
+		711: "Redirect Error",
+		712: "Controlled Shutdown",
+		713: "SSL Handshake Failure",
+		714: "Connection Failure",
+		715: "Response Header Error",
+		716: "Protocol Switching Failure",
+		717: "Invalid Cotnent Type",
+		718: "Unacceptable Content Type",	
+		720: "HTTP2 Connection Closed",
+		721: "HTTP2 Stream Reset"
 }
 
-def get (code, default):
+def get (code, default = "Undefined Error"):
 	return responses.get (code, default)
 	
 	
